@@ -6,16 +6,19 @@ from pydantic_settings import BaseSettings, SettingsConfigDict
 
 class PostgresSettings(BaseSettings):
     host: str = "localhost"
-    name: str
+    port: int | str = 5432
+    name: str = ""
     password: Optional[str] = None
     username: Optional[str] = None
     model_config = SettingsConfigDict(
         case_sensitive=False,
         extra="ignore",
-        env_nested_delimiter="__",
         env_prefix="db_",
     )
 
+    def get_url(self) -> str:
+        return f"postgresql+psycopg://{self.username}:{self.password}@{self.host}:{self.port}/{self.name}"
+
 
 class Context:
     settings: Optional[PostgresSettings] = None
@@ -25,7 +28,8 @@ __ctx = Context()
 
 
 def init_settings(root: Path):
-    __ctx.settings = PostgresSettings(_env_file=root / ".env")
+    PostgresSettings.model_config.update(env_file=root / ".env")
+    __ctx.settings = PostgresSettings()
 
 
 def get_settings() -> PostgresSettings:
@@ -33,3 +37,8 @@ def get_settings() -> PostgresSettings:
         msg = "Settings are not initialized -- call init_settings()"
         raise Exception(msg)
     return __ctx.settings
+
+
+if __name__ == "__main__":
+    settings = PostgresSettings(port="443", name="fake")
+    print(settings.port)
